@@ -271,7 +271,7 @@ bool KFilePlacesViewDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *vi
     if (event->type() == QHelpEvent::ToolTip) {
         if (pointIsTeardownAction(event->pos())) {
             if (auto *placesModel = qobject_cast<const KFilePlacesModel *>(index.model())) {
-                Q_ASSERT(placesModel->isTeardownAllowed(index));
+                Q_ASSERT(placesModel->isTeardownOverlayRecommended(index));
 
                 QString toolTipText;
 
@@ -396,7 +396,7 @@ bool KFilePlacesViewDelegate::pointIsTeardownAction(const QPoint &pos) const
         return false;
     }
 
-    if (!index.data(KFilePlacesModel::TeardownAllowedRole).toBool()) {
+    if (!index.data(KFilePlacesModel::TeardownOverlayRecommendedRole).toBool()) {
         return false;
     }
 
@@ -753,7 +753,7 @@ KFilePlacesView::KFilePlacesView(QWidget *parent)
 
     d->m_watcher->m_scroller = QScroller::scroller(viewport());
     QScrollerProperties scrollerProp;
-    scrollerProp.setScrollMetric(QScrollerProperties::AcceleratingFlickMaximumTime, 0.2); //QTBUG-88249
+    scrollerProp.setScrollMetric(QScrollerProperties::AcceleratingFlickMaximumTime, 0.2); // QTBUG-88249
     d->m_watcher->m_scroller->setScrollerProperties(scrollerProp);
     d->m_watcher->m_scroller->grabGesture(viewport());
     connect(d->m_watcher->m_scroller, &QScroller::stateChanged, d->m_watcher, &KFilePlacesEventWatcher::qScrollerStateChanged);
